@@ -6,7 +6,7 @@ import calendar
 
 NON_SALES_COLS = ['Ticker','quarter_end','date', 'eps_estimate',
        'eps_reported', 'gaap_eps', 'quarter', 'reported_revenue',
-       'revenue_estimate', 'symbol', "total_dollars", "eps","profit","revenue", "ann_date", "SALES_REV_TURN","GROSS_PROFIT","ARD_GROSS_PROFITS","IS_EPS", "IS_COMP_EPS_ADJUSTED", "IS_BASIC_EPS_CONT_OPS", "ARD_ADJUSTED_EPS","IS_ADJUSTED_EPS_AS_REPORTED", "BEST_SALES","BEST_EPS"]
+       'revenue_estimate', 'symbol', "total_dollars", "eps","profit","revenue", "ann_date","q_datetime","calendar_type", "SALES_REV_TURN","GROSS_PROFIT","ARD_GROSS_PROFITS","IS_EPS", "IS_COMP_EPS_ADJUSTED", "IS_BASIC_EPS_CONT_OPS", "ARD_ADJUSTED_EPS","IS_ADJUSTED_EPS_AS_REPORTED", "BEST_SALES","BEST_EPS"]
 
 def get_quarter_end(date, calendar_type):
 
@@ -49,6 +49,7 @@ def create_dataset(ew_data):
     ew_data = ew_data.rename(columns={"Ticker":"symbol"})
     
     all_data = ew_data.merge(bdata, on=["symbol","quarter_end"])
+    all_data["total_dollars"] = all_data[[x for x in all_data.columns if x not in NON_SALES_COLS]].sum(axis=1)
     return all_data
 
 def run_summary_cat_report(output_dir, df):
